@@ -13,7 +13,7 @@ use Mozilla::CA;
 
 use vars qw[ $VERSION ];
 
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 BEGIN {
   Finance::Bank::Postbank_de->mk_accessors(qw( agent login password urls ));
@@ -560,3 +560,29 @@ Max Maischein, E<lt>corion@cpan.orgE<gt>
 =head1 SEE ALSO
 
 L<perl>, L<WWW::Mechanize>.
+
+=head1 REPOSITORY
+
+The public repository of this module is 
+L<https://github.com/Corion/Finance-Bank-Postbank_de>.
+
+=head1 SUPPORT
+
+The public support forum of this module is
+L<http://perlmonks.org/>.
+
+=head1 BUG TRACKER
+
+Please report bugs in this module via the RT CPAN bug queue at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Finance-Bank-Postbank_de>
+or via mail to L<finance-bank-postbank_de-Bugs@rt.cpan.org>.
+
+=head1 COPYRIGHT (c)
+
+Copyright 2003-2015 by Max Maischein C<corion@cpan.org>.
+
+=head1 LICENSE
+
+This module is released under the same terms as Perl itself.
+
+=cut
