@@ -9,7 +9,7 @@ use base 'Class::Accessor';
 
 use vars qw[ $VERSION %tags %totals %columns %safety_check ];
 
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 BEGIN {
   Finance::Bank::Postbank_de::Account->mk_accessors(qw( number balance balance_unavailable balance_prev transactions_future iban blz account_type name));
@@ -78,9 +78,10 @@ sub parse_date {
 
 sub parse_amount {
   my ($self,$amount) = @_;
+  # ' 5.314,05'
   die "String '$amount' does not look like a number"
-    unless $amount =~ /^(-?[0-9]{1,3}(?:\.\d{3})*,\d{2})(?:\s*\x{20AC}|\s*\x{80})?$/;
-  $amount = $1;
+    unless $amount =~ /^(-?)(?:\s*\x{20AC}\s*|\s*\x{80}\s*|\s*\x{A4}\s*)?([0-9]{1,3}(?:\.\d{3})*,\d{2})(?:\s*\x{20AC}|\s*\x{80})?$/;
+  $amount = ($1||'') . $2;
   $amount =~ tr/.//d;
   $amount =~ s/,/./;
   $amount;
